@@ -273,7 +273,7 @@ class CodePipeline(Base):
     def retry_fail_stage(self, pl_name, stage_name, exec_id):
         """Retry Falied Actin in a stage"""
 
-        logger.info(f"set_approval_result for {pl_name}")
+        logger.info(f"retry_fail_stage for {pl_name=} {stage_name=} {exec_id=}")
 
         param = {
             "pipelineName": pl_name,
@@ -579,11 +579,10 @@ class CodePipeline(Base):
 
         # Find Action
         for stage in self.pipeline.get("stages", []):
-            stage_name = stage.get("name", "")
-
             for action in stage.get("actions", []):
                 if action["id"] == index:
-                    exec_id = stage.get("latestExecution", {}).get(
+                    stage_name = stage.get("name", "")
+                    pipeline_exec_id = stage.get("latestExecution", {}).get(
                         "pipelineExecutionId", "na"
                     )
                     self.action = action
@@ -592,6 +591,7 @@ class CodePipeline(Base):
             return
 
         print("--- Action Details ---")
+        print(f"Pipeline Exec ID: {pipeline_exec_id}")
         pprint.pprint(self.action)
 
         status = self.action.get("status", "")
@@ -632,7 +632,6 @@ class CodePipeline(Base):
             )
 
         if status == "Failed":
-            exec_id = "TBD"
 
             if action_provider == "CodeBuild":
                 key = o7i.input_string("Option -> Retry(r) Details(d) Back (any) :")
@@ -641,7 +640,9 @@ class CodePipeline(Base):
 
             if key == "r":
                 self.retry_fail_stage(
-                    pl_name=self.pipeline_name, stage_name=stage_name, exec_id=exec_id
+                    pl_name=self.pipeline_name,
+                    stage_name=stage_name,
+                    exec_id=pipeline_exec_id,
                 )
             elif key == "d":
                 o7cli.codebuild.CodeBuild(
