@@ -16,7 +16,6 @@
 # ************************************************************************
 """Module allows to view and access Security Hub resources"""
 
-
 # --------------------------------
 #
 # --------------------------------
@@ -114,7 +113,6 @@ class SecurityHub(Base):
             )
 
         except botocore.exceptions.ClientError:
-
             logger.info("Not allowed to list accounts for organization")
             self.df_accounts = pd.DataFrame(
                 [
@@ -219,7 +217,6 @@ class SecurityHub(Base):
         self.df_controls = None
 
         for standards, row in df_ready.iterrows():
-
             controls = []
 
             #
@@ -436,7 +433,6 @@ class SecurityHub(Base):
     #
     # *************************************************
     def find_dynamodb_table_with_tag(self, tag_key, tag_value):
-
         dynamodb = self.session.client("dynamodb")
         matching_tables = []
 
@@ -469,6 +465,38 @@ class SecurityHub(Base):
 
         return self
 
+    # *************************************************
+    #
+    # *************************************************
+    def write_historical_data(self):
+        """Write historical data"""
+
+        tables = self.find_dynamodb_table_with_tag("Purpose", "sechub-findings-history")
+        if len(tables) != 1:
+            print("Historical table not found")
+            return
+
+        for table in tables:
+            self.write_to_dynamodb(table)
+
+        return self
+
+    # *************************************************
+    #
+    # *************************************************
+    def migrate_historical_data(self):
+        """Load historical data"""
+
+        tables = self.find_dynamodb_table_with_tag("Purpose", "sechub-findings-history")
+        if len(tables) != 1:
+            print("Historical table not found")
+            return
+
+        for table in tables:
+            self.migrate_dynamodb_date(table)
+
+        return self
+
     # *************************************************
     #
     # *************************************************
@@ -752,7 +780,6 @@ class SecurityHub(Base):
             df_results = None
 
         if df_results is not None:
-
             self.findings_per_account = df_results.reset_index()  #
             params = TableParam(
                 with_group=True,
@@ -1046,7 +1073,6 @@ class SecurityHub(Base):
         ret = []
 
         for index, standard in self.df_standards.iterrows():  # noqa: B007
-
             if standard["StandardsStatus"] != "READY":
                 continue
 
@@ -1375,7 +1401,6 @@ class SecurityHub(Base):
 
         print("")
         if self.df_findings is not None:
-
             findings_compile = self.compile_findings_per_accounts()
             total = findings_compile["Finding"].sum()
             sh_failed = findings_compile["Failed"].sum()
@@ -1421,7 +1446,6 @@ class SecurityHub(Base):
 
         filename = f"aws-securityhub-{datetime.datetime.now().isoformat()[0:19].replace(':','-')}.xlsx"
         with pd.ExcelWriter(filename) as writer:
-
             df_parameters = pd.DataFrame(
                 [
                     {"Parameter": "Date", "Value": datetime.datetime.now().isoformat()},
@@ -1704,7 +1728,6 @@ class SecurityHub(Base):
         print(findings["ProductName"].unique())
 
         for section in sections:
-
             section_findings = findings[findings["ProductName"] == section["product"]]
             count = len(section_findings.index)
             section_max = section["max"]
@@ -1727,7 +1750,6 @@ class SecurityHub(Base):
         other_findings = findings[~findings["ProductName"].isin(all_product)]
         count = len(other_findings.index)
         if count > 0:
-
             section_params = TableParam(
                 columns=[
                     ColumnParam(title="Source", type="str", data_col="ProductName"),
@@ -1781,25 +1803,25 @@ class SecurityHub(Base):
             self.load_standard_controls()
 
         self.calculate_controls_and_standards()
-        stats_per_account = self.compile_findings_per_accounts()
 
-        for account in stats_per_account.to_dict(orient="records"):
+        for (standard, account_id), stats in self.df_standards_results.iterrows():
+            print(f"Writing to DynamoDB: {standard} - {account_id}")
             item = {
-                "account": account["AwsAccountId"],
+                "account": account_id,
                 "date": today,
-                "critical": account["Critical"],
-                "high": account["High"],
-                "medium": account["Medium"],
-                "low": account["Low"],
+                "short": self.df_standards.loc[standard]["Short"],
+                "critical": int(stats["FindingsCritical"]),
+                "high": int(stats["FindingsHigh"]),
+                "medium": int(stats["FindingsMedium"]),
+                "low": int(stats["FindingsLow"]),
+                "ctrl_critical": int(stats["Critical"]),
+                "ctrl_high": int(stats["High"]),
+                "ctrl_medium": int(stats["Medium"]),
+                "ctrl_low": int(stats["Low"]),
+                "ctrl_active": int(stats["ControlsActive"]),
+                "ctrl_total": int(stats["Controls"]),
+                "score": Decimal(f"{stats['Score']:.4f}"),
             }
-
-            for _index, row in self.df_standards[
-                self.df_standards["StandardsStatus"] == "READY"
-            ].iterrows():
-                std_short = row["Short"]
-                item[std_short] = Decimal(f"{account[std_short]:.4f}")
-
-            # pprint.pprint(item)
             table.put_item(Item=item)
 
     # *************************************************
@@ -1842,6 +1864,49 @@ class SecurityHub(Base):
         ret = pd.DataFrame(items)
         return ret
 
+    # *************************************************
+    #
+    # *************************************************
+    def migrate_dynamodb_date(self, table_name: str):
+        """Migrate DynamoDB date"""
+
+        df = self.read_history_from_dynamodb(table_name=table_name, number_days=180)
+
+        dynamodb = self.session.resource("dynamodb")
+        table = dynamodb.Table(table_name)
+
+        print(df.head(5))
+        for _index, row in df.iterrows():
+
+            short = row.get("short", None)
+            today = row["date"]
+            account_id = row["account"]
+
+            if not pd.isna(short):
+                print(f"Skipping: {account_id} - {today} - {short}")
+                continue
+
+            if not pd.isna(row.get("CIS v3.0.0", None)):
+                short = "CIS v3.0.0"
+                score = row.get("CIS v3.0.0", None)
+
+            elif not pd.isna(row.get("NIST 800-53", None)):
+                short = "NIST 800-53"
+                score = row.get("NIST 800-53", None)
+
+            print(f"Writing to DynamoDB: {account_id} - {today}")
+            item = {
+                "account": account_id,
+                "date": today,
+                "short": short,
+                "critical": int(row["critical"]),
+                "high": int(row["high"]),
+                "medium": int(row["medium"]),
+                "low": int(row["low"]),
+                "score": Decimal(f"{score:.4f}"),
+            }
+            table.put_item(Item=item)
+
     # *************************************************
     #
     # *************************************************
@@ -2111,14 +2176,6 @@ class SecurityHub(Base):
                 callback=self.update_findings,
             )
         )
-        obj.add_option(
-            o7m.Option(
-                key="h",
-                name="Load Historical data",
-                short="History",
-                callback=self.load_historical_data,
-            )
-        )
         obj.add_option(
             o7m.Option(
                 key="a",
@@ -2137,7 +2194,10 @@ class SecurityHub(Base):
         )
         obj.add_option(
             o7m.Option(
-                key="x", name="Save To Excel", short="To Excel", callback=self.to_excel
+                key="excel",
+                name="Save To Excel",
+                short="To Excel",
+                callback=self.to_excel,
             )
         )
         obj.add_option(
@@ -2166,6 +2226,31 @@ class SecurityHub(Base):
             )
         )
 
+        obj.add_option(
+            o7m.Option(
+                key="load",
+                name="Load Historical data from Dynamo",
+                short="History",
+                callback=self.load_historical_data,
+            )
+        )
+        obj.add_option(
+            o7m.Option(
+                key="write",
+                name="Write Historical data to Dynamo",
+                short="To DDb",
+                callback=self.write_historical_data,
+            )
+        )
+        obj.add_option(
+            o7m.Option(
+                key="migrate",
+                name="Migrate Historical data to Dynamo",
+                short="migrate",
+                callback=self.migrate_historical_data,
+            )
+        )
+
         obj.add_option(
             o7m.Option(
                 key="int",
@@ -2193,7 +2278,6 @@ def menu(**kwargs):
 #
 # *************************************************
 if __name__ == "__main__":
-
     pd.set_option("display.max_rows", None)
     pd.set_option("display.max_columns", None)
     pd.set_option("display.width", o7t.get_width())
